# Sidebar

## A title in the sidebar

This is the sidebar. It won't show up when you print. You can edit or remove it by editing _footer.html. You can use jinja tags here like 1 + 1 = {{ 1+1 }}, but remember if you want to reference any files you need to add them as inputs in the .dexy config file.

### What a nice rhythm

Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.

## Atatonic

### With a sweet subtitle. Yes it is a sweet one.

This look and feel comes from Atatonic, a nice little typography-oriented CSS framework. Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.

##### Atatonic notice

This is a basic notice message, without a header it might even look nicer.

##### Success

This is a basic success message

##### Error

Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.